@@ -80,35 +80,68 @@
  * # DLL-Optionen fr Windows                                           #
  * # Der DLL-Code wurde aus der Datei dllhelpers (beim MinGW-Compiler   #
  * # enthalten, http://www.mingw.org/) entnommen                        #
+ * #                                                                    #
+ * # Falls das Makro USE_CDECL gesetzt ist, wird als Aufrufmethode      #
+ * # CDECL genommen, ansonsten STDCALL (Default).                       #
  * ######################################################################
  */
 
-#if BUILD_DLL /* DLL kompilieren */
-# define DLL_EXPORT __declspec (dllexport) __stdcall 
-# define DLL_EXPORT_V __declspec (dllexport)
-#elif USE_DLL /* DLL in einem anderen Programm benutzen */
-# define DLL_EXPORT __declspec (dllimport) __stdcall 
-# define DLL_EXPORT_V __declspec (dllimport)
-#else /* kein DLL-Krempel erforderlich */
-# define DLL_EXPORT
-# define DLL_EXPORT_V
+#if USE_CDECL
+#  if BUILD_DLL /* DLL kompilieren */
+#    define DLL_EXPORT __declspec (dllexport)
+#    define DLL_EXPORT_V __declspec (dllexport)
+#  elif USE_DLL /* DLL in einem anderen Programm benutzen */
+#    define DLL_EXPORT __declspec (dllimport)
+#    define DLL_EXPORT_V __declspec (dllimport)
+#  else /* kein DLL-Krempel erforderlich */
+#    define DLL_EXPORT
+#    define DLL_EXPORT_V
+#  endif
+#else
+#   if BUILD_DLL /* DLL kompilieren */
+#    define DLL_EXPORT __declspec (dllexport) __stdcall 
+#    define DLL_EXPORT_V __declspec (dllexport)
+#  elif USE_DLL /* DLL in einem anderen Programm benutzen */
+#    define DLL_EXPORT __declspec (dllimport) __stdcall 
+#    define DLL_EXPORT_V __declspec (dllimport)
+#  else /* kein DLL-Krempel erforderlich */
+#    define DLL_EXPORT
+#    define DLL_EXPORT_V
+#  endif
 #endif
 
 #ifdef _WIN32
 #define localtime_r(timep,result) localtime(timep)
 #endif
 
+/*
+ * ######################################################################
+ * #          Defaultnamen und Suchpfad fr die LUT-Datei               #
+ * ######################################################################
+ */
+
+#define DEFAULT_LUT_NAME "blz.lut","blz.lut2","blz.lut1"
+
+#if _WIN32
+#define DEFAULT_LUT_PATH ".","C:","C:\\Programme\\konto_check"
+#else
+#define DEFAULT_LUT_PATH ".","/usr/local/etc","/etc","/usr/local/bin","/opt/konto_check"
+#endif
+
+   /* maximale Lnge fr Default-Suchpfad und Dateiname der LUT-Datei */
+#define LUT_PATH_LEN 128
+
 /*
  * ######################################################################
  * #               Felder fr die LUT-Datei (ab LUT-Version 2.0)        #
  * ######################################################################
  */
 
-#define DEFAULT_LUT_FIELDS_NUM   6
-#define DEFAULT_LUT_FIELDS       lut_set_6
-#define DEFAULT_LUT_NAME         "blz.lut"
+#define DEFAULT_LUT_FIELDS_NUM   5
+#define DEFAULT_LUT_FIELDS       lut_set_5
 #define DEFAULT_LUT_VERSION      3
 #define DEFAULT_SLOTS            26
+#define DEFAULT_INIT_LEVEL       5
 
 #define LUT2_BLZ                      1
 #define LUT2_FILIALEN                 2
@@ -149,6 +182,7 @@
  */
 
 #undef FALSE
+#define INVALID_SET                            -75
 #define NO_GERMAN_BIC                          -74
 #define IPI_CHECK_INVALID_LENGTH               -73
 #define IPI_INVALID_CHARACTER                  -72
@@ -231,9 +265,8 @@
 #define LUT2_NO_VALID_DATE                       5
 #define LUT1_SET_LOADED                          6
 #define LUT1_FILE_GENERATED                      7
-#line 128 "konto_check_h.lx"
+#line 161 "konto_check_h.lx"
 
-#define DEFAULT_LUT_NAME  "blz.lut"
 #define MAX_BLZ_CNT 30000  /* maximale Anzahl BLZ's in generate_lut() */
 
 /*
@@ -482,7 +515,7 @@ DLL_EXPORT int generate_lut2_p(char *inputname,char *outputname,char *user_info,
 DLL_EXPORT int generate_lut2(char *inputname,char *outputname,char *user_info,
       char *gueltigkeit,UINT4 *felder,UINT4 slots,UINT4 lut_version,UINT4 set);
 DLL_EXPORT int copy_lutfile(char *old_name,char *new_name,int new_slots);
-DLL_EXPORT int lut_init(char *lut_name,UINT4 *required,int **status,UINT4 set,UINT4 incremental);
+DLL_EXPORT int lut_init(char *lut_name,UINT4 required,UINT4 set);
 DLL_EXPORT int kto_check_init(char *lut_name,UINT4 *required,int **status,UINT4 set,UINT4 incremental);
 DLL_EXPORT int kto_check_init2(char *lut_name);
 DLL_EXPORT int *lut2_status(void);
@@ -492,6 +525,7 @@ DLL_EXPORT int lut_valid(void);
 DLL_EXPORT int get_lut_info2(char *lut_name,int *version_p,char **prolog_p,char **info_p,char **user_info_p);
 DLL_EXPORT int get_lut_info_b(char **info,char *lutname);
 DLL_EXPORT int get_lut_info2_b(char *lutname,int *version,char **prolog_p,char **info_p,char **user_info_p);
+DLL_EXPORT int get_lut_id(char *lut_name,int set,char *id);
 DLL_EXPORT int rebuild_blzfile(char *inputname,char *outputname,UINT4 set);
 DLL_EXPORT int dump_lutfile(char *outputname,UINT4 *required);
 DLL_EXPORT int dump_lutfile_p(char *outputname,UINT4 felder);
@@ -528,6 +562,7 @@ DLL_EXPORT int ipi_check(char *zweck);
 DLL_EXPORT char *kto_check_retval2txt(int retval);
 DLL_EXPORT char *kto_check_retval2txt_short(int retval);
 DLL_EXPORT char *kto_check_retval2html(int retval);
+DLL_EXPORT char *kto_check_retval2utf8(int retval);
 DLL_EXPORT char *kto_check_retval2dos(int retval);
 
 /*
