@@ -12,17 +12,18 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw( kto_check kto_check_str kto_check_blz
    kto_check_pz generate_lut generate_lut2 lut_cleanup lut_valid
-   kto_check_init copy_lutfile lut_multiple lut_filialen lut_name
-   lut_name_kurz lut_plz lut_ort lut_pan lut_bic lut_pz lut_aenderung
-   lut_loeschung lut_nachfolge_blz lut_info iban2bic iban_gen
-   check_iban ipi_check ipi_gen kto_check_retval2txt
-   kto_check_retval2txt_short kto_check_retval2html dump_lutfile
-   kto_check_retval2dos konto_check_at kto_check_at_str
-   generate_lut_at %kto_retval %kto_retval_kurz );
+   lut_init kto_check_init copy_lutfile lut_multiple lut_filialen
+   lut_name lut_name_kurz lut_plz lut_ort lut_pan lut_bic lut_pz
+   lut_aenderung lut_loeschung lut_nachfolge_blz lut_info iban2bic
+   iban_gen check_iban ipi_check ipi_gen kto_check_retval2txt
+   kto_check_retval2txt_short kto_check_retval2utf8
+   kto_check_retval2html dump_lutfile kto_check_retval2dos
+   konto_check_at kto_check_at_str generate_lut_at %kto_retval
+   %kto_retval_kurz );
 
-our @EXPORT = qw( kto_check kto_check_init kto_check_blz kto_check_at %kto_retval );
+our @EXPORT = qw( kto_check lut_init kto_check_blz kto_check_at %kto_retval );
 
-our $VERSION = '2.91';
+our $VERSION = '2.92';
 
 require XSLoader;
 XSLoader::load('Business::KontoCheck', $VERSION);
@@ -274,6 +275,7 @@ sub lut_nachfolge_blz
 
 
 %Business::KontoCheck::kto_retval = (
+ -75 => 'fr ein LUT-Set sind nur die Werte 0, 1 oder 2 mglich',
  -74 => 'Ein Konto kann kann nur fr deutsche Banken geprft werden',
  -73 => 'Der zu validierende strukturierete Verwendungszweck mu genau 20 Zeichen enthalten',
  -72 => 'Im strukturierten Verwendungszweck drfen nur alphanumerische Zeichen vorkommen',
@@ -357,6 +359,7 @@ sub lut_nachfolge_blz
    6 => 'Die Datei ist im alten LUT-Format (1.0/1.1)',
    7 => 'OK; es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert (version<3)',
 
+'INVALID_SET'                            => 'fr ein LUT-Set sind nur die Werte 0, 1 oder 2 mglich',
 'NO_GERMAN_BIC'                          => 'Ein Konto kann kann nur fr deutsche Banken geprft werden',
 'IPI_CHECK_INVALID_LENGTH'               => 'Der zu validierende strukturierete Verwendungszweck mu genau 20 Zeichen enthalten',
 'IPI_INVALID_CHARACTER'                  => 'Im strukturierten Verwendungszweck drfen nur alphanumerische Zeichen vorkommen',
@@ -442,6 +445,7 @@ sub lut_nachfolge_blz
 );
 
 %Business::KontoCheck::kto_retval_kurz = (
+ -75 => 'INVALID_SET',
  -74 => 'NO_GERMAN_BIC',
  -73 => 'IPI_CHECK_INVALID_LENGTH',
  -72 => 'IPI_INVALID_CHARACTER',
@@ -545,6 +549,7 @@ language is german too.
    use Business::KontoCheck;
    use Business::KontoCheck qw( kto_check lut_name lut_blz lut_ort %kto_retval [...] );
 
+   $retval=lut_init([$lut_name[,$required[,$set]]);
    $retval=kto_check_init($lut_name[,$required[,$set[,$incremental]]]);
    $retval=kto_check($blz,$kto,$lut_name);
    $retval=kto_check_str($blz,$kto,$lut_name);
@@ -578,6 +583,7 @@ language is german too.
    $retval=retval2txt($retval)
    $retval=retval2txt_short($retval)
    $retval=retval2html($retval)
+   $retval=retval2utf8($retval)
    $retval=retval2dos($retval)
    $retval_txt=$kto_retval{$retval};
 
